@@ -26,22 +26,20 @@
 
 This AWS Solutions Construct implements an AWS CloudFront fronting an Amazon API Gateway REST API.
 
-Here is a minimal deployable pattern definition:
+Here is a minimal deployable pattern definition in Typescript:
 
 ```javascript
-const api = require('@aws-cdk/aws-apigateway');
-const lambda = require("@aws-cdk/aws-lambda");
-const { CloudFrontToApiGateway } = require('@aws-solutions-constructs/aws-cloudfront-apigateway');
-
-const stack = new Stack();
+import * as api from '@aws-cdk/aws-apigateway';
+import * as lambda from "@aws-cdk/aws-lambda";
+import { CloudFrontToApiGateway } from '@aws-solutions-constructs/aws-cloudfront-apigateway';
 
 const lambdaProps: lambda.FunctionProps = {
-    code: lambda.Code.asset(`${__dirname}/lambda`),
+    code: lambda.Code.fromAsset(`${__dirname}/lambda`),
     runtime: lambda.Runtime.NODEJS_12_X,
     handler: 'index.handler'
 };
 
-const lambdafunction = new lambda.Function(stack, 'LambdaFunction', lambdaProps);
+const lambdafunction = new lambda.Function(this, 'LambdaFunction', lambdaProps);
 
 const apiGatewayProps: api.LambdaRestApiProps = {
         handler: lambdafunction,
@@ -53,9 +51,9 @@ const apiGatewayProps: api.LambdaRestApiProps = {
         }
 };
 
-const apiGateway = new api.LambdaRestApi(scope, 'LambdaRestApi', apiGatewayProps);
+const apiGateway = new api.LambdaRestApi(this, 'LambdaRestApi', apiGatewayProps);
 
-new CloudFrontToApiGateway(stack, 'test-cloudfront-apigateway', {
+new CloudFrontToApiGateway(this, 'test-cloudfront-apigateway', {
     existingApiGatewayObj: apiGateway
 });
 
@@ -153,12 +151,9 @@ class CloudFrontToApiGateway(
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
 
-        access:
-        :access:: public
-        since:
-        :since:: 0.8.0
-        summary:
-        :summary:: Constructs a new instance of the CloudFrontToApiGateway class.
+        :access: public
+        :since: 0.8.0
+        :summary: Constructs a new instance of the CloudFrontToApiGateway class.
         """
         props = CloudFrontToApiGatewayProps(
             existing_api_gateway_obj=existing_api_gateway_obj,
@@ -215,8 +210,7 @@ class CloudFrontToApiGatewayProps:
         :param cloud_front_distribution_props: Optional user provided props to override the default props. Default: - Default props are used
         :param insert_http_security_headers: Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront. Default: - true
 
-        summary:
-        :summary:: The properties for the CloudFrontToApiGateway Construct
+        :summary: The properties for the CloudFrontToApiGateway Construct
         """
         self._values: typing.Dict[str, typing.Any] = {
             "existing_api_gateway_obj": existing_api_gateway_obj,
@@ -230,7 +224,6 @@ class CloudFrontToApiGatewayProps:
     def existing_api_gateway_obj(self) -> aws_cdk.aws_apigateway.RestApi:
         """Existing instance of api.RestApi object.
 
-        default
         :default: - None
         """
         result = self._values.get("existing_api_gateway_obj")
@@ -241,7 +234,6 @@ class CloudFrontToApiGatewayProps:
     def cloud_front_distribution_props(self) -> typing.Any:
         """Optional user provided props to override the default props.
 
-        default
         :default: - Default props are used
         """
         result = self._values.get("cloud_front_distribution_props")
@@ -251,7 +243,6 @@ class CloudFrontToApiGatewayProps:
     def insert_http_security_headers(self) -> typing.Optional[builtins.bool]:
         """Optional user provided props to turn on/off the automatic injection of best practice HTTP security headers in all responses from cloudfront.
 
-        default
         :default: - true
         """
         result = self._values.get("insert_http_security_headers")
